@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Die;
 use vars '$VERSION';
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 use base 'Exporter';
 
@@ -37,13 +37,14 @@ sub die_decode($)
     $text[0] =~ s/\s*[.:;]?\s*$err\s*$//  # the $err is translation sensitive
         or delete $opt{errno};
 
-    my $msg = shift @text;
-    length $msg or $msg = 'stopped';
+    my @msg = shift @text;
+    length $msg[0] or $msg[0] = 'stopped';
 
     my @stack;
     foreach (@text)
-    {   push @stack, [ $1, $2, $3 ]
-            if m/^\s*(.*?)\s+called at (.*?) line (\d+)\s*$/;
+    {   if(m/^\s*(.*?)\s+called at (.*?) line (\d+)\s*$/)
+             { push @stack, [ $1, $2, $3 ] }
+        else { push @msg, $_ }
     }
     $opt{stack}   = \@stack;
     $opt{classes} = [ 'perl', (@stack ? 'confess' : 'die') ];
@@ -52,7 +53,7 @@ sub die_decode($)
       = @{$opt{stack}} ? ($opt{errno} ? 'ALERT' : 'PANIC')
       :                  ($opt{errno} ? 'FAULT' : 'ERROR');
 
-    ($dietxt, \%opt, $reason, $msg);
+    ($dietxt, \%opt, $reason, join("\n",@msg));
 }
 
 "to die or not to die, that's the question";
