@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::File;
 use vars '$VERSION';
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 use base 'Log::Report::Dispatcher';
 
@@ -56,7 +56,7 @@ sub init($)
       : $format eq 'LONG'
       ? sub { my $msg    = shift;
               my $domain = shift || '-';
-              my $stamp  = strftime "%FT%T", gmtime;
+              my $stamp  = strftime "%Y-%m-%dT%H:%M:%S", gmtime;
               "[$stamp $$] $domain $msg"
             }
       : error __x"unknown format parameter `{what}'"
