@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,12 +7,13 @@ use strict;
 
 package Log::Report::Exception;
 use vars '$VERSION';
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 
 use Log::Report      'log-report';
 use Log::Report::Util qw/is_fatal/;
 use POSIX             qw/locale_h/;
+use Scalar::Util      qw/blessed/;
 
 
 use overload
@@ -43,8 +44,8 @@ sub message(;$)
 {   my $self = shift;
     @_ or return $self->{message};
     my $msg = shift;
-    UNIVERSAL::isa($msg, 'Log::Report::Message')
-        or panic __x"message() of exception expects Log::Report::Message";
+    blessed $msg && $msg->isa('Log::Report::Message')
+        or panic "message() of exception expects Log::Report::Message";
     $self->{message} = $msg;
 }
 
